import objectdraw.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Random;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JSlider;
import javax.swing.JPanel;

/*
 * Example NestedSquaresSizes: draw nested squares objects 
 * of various sizes, drag them around, and
 *
 * Jim Teresco, The College of Saint Rose, CSC 252, Fall 2013
 *
 * $Id: NestedSquaresSizes.java 2333 2014-03-12 17:48:14Z terescoj $
 */

public class NestedSquaresSizes extends WindowController
    implements ActionListener  {
   
    // minimum and maximum sizes for our objects
    private static final int MIN_SIZE = 25;
    private static final int MAX_SIZE = 200;
    
    // standard dragging stuff
    private NestedSquares newestSquares;
    private boolean dragging;
    private Location lastMouse;
   
    // a slider to determine the size of the next box to 
    // create
    private JSlider nextBoxSize;
    
    // a "set color" and "get info" button
    // used to modify or report on the newest
    // NestedSquares object in existence
    private JButton setColor, getInfo;
    
    // a label where the "info" will be reported
    private JLabel infoLabel;
    
    // we'll need some random numbers too
    private Random r = new Random();
    
    public void begin() {
        
        setSize(500, 600);
        
        // get the content pane to which we can add items
        Container contentPane = getContentPane();
        
        // we'll put our buttons and slider into a panel
        // at the bottom of the window
        JPanel southPanel = new JPanel();
        
        // our buttons
        setColor = new JButton("Random Color");
        southPanel.add(setColor);
        setColor.addActionListener(this);
        
        getInfo = new JButton("Get Info");
        southPanel.add(getInfo);
        getInfo.addActionListener(this);
        
        // a slider to control sizes
        nextBoxSize = new JSlider(JSlider.HORIZONTAL, MIN_SIZE, MAX_SIZE,
            (MIN_SIZE + MAX_SIZE)/2);
        // with some labels for end amounts?
        southPanel.add(new JLabel(""+MIN_SIZE));
        southPanel.add(nextBoxSize);
        southPanel.add(new JLabel(""+MAX_SIZE));
        
        // add our panel in the south
        contentPane.add(southPanel, BorderLayout.SOUTH);
        
        // create a Label for information
        infoLabel = new JLabel("Info will appear here when you click \"Get Info\"");
        contentPane.add(infoLabel, BorderLayout.NORTH);
        
        contentPane.validate();

    }
    
    public void onMousePress(Location point) {

        if (newestSquares != null && newestSquares.contains(point)) {
            dragging = true;
            lastMouse = point;
        }
        else {
            newestSquares = new NestedSquares(point.getX(), point.getY(), nextBoxSize.getValue(), canvas);
	    dragging = false;
        }
    }
    
    public void onMouseDrag(Location point) {
        
        if (dragging) {
            newestSquares.move(point.getX() - lastMouse.getX(),
                               point.getY() - lastMouse.getY());
            lastMouse = point;
        }
    }
    
    public void onMouseRelease(Location point) {
        
        if (dragging) {
            newestSquares.move(point.getX() - lastMouse.getX(),
                               point.getY() - lastMouse.getY());
            lastMouse = point;
        }
    }
    
    // event handler to react to our buttons
    public void actionPerformed(ActionEvent e) {
        
        if (e.getSource() == getInfo) {
            // it's the get info button
            if (newestSquares != null) {
                int numLevels = newestSquares.squareCount();
                double totalPerimeter = newestSquares.totalPerimeter();
                infoLabel.setText("Newest has " + numLevels + " squares, total perimeter: " + totalPerimeter);
            }
            else {
                infoLabel.setText("Please create a nested squares first!");
            }
        }
        else {
            // must be the setColor button
            if (newestSquares != null) {
                Color c = new Color(r.nextInt(256), r.nextInt(256), r.nextInt(256));
                newestSquares.setColor(c);
            }
        }
    }
}
